/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code Small Screen Rendering XPI.
 *
 * The Initial Developer of the Original Code is
 * Daniel Glazman.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var ssrUtils = {
  toggleSSR : function (e) {
    //const cSSRSheetURL  = "chrome://xsidebar/content/webpanels/smallscreenrendering.css";
    const cSSRSheetURL  = "resource://xsidebar/smallscreenrendering.css";

    this.setResource();

    //var doc         = window._content.document;
    var doc         = getWebPanelBrowser().contentDocument;
    var docRoot     = doc.documentElement;
    var docRootName = docRoot.nodeName.toLowerCase();

    // is the document using frames ? we don't like frames for the moment
    if (docRootName == "html" &&
        doc.body.nodeName.toLowerCase() == "frameset") {
      //var ps = Components.classes[PROMPTSERVICE_CONTRACTID].getService(nsIPromptService);
      //ps.alert(null, "Small Screen Rendering",
      //         "No frames allowed");
      dump("Small Screen Rendering, No frames allowed");
      return;
    }

    var styleSheets = doc.styleSheets;
    var lastOwnerNode = null;
    for (var i = 0; i < styleSheets.length; ++i) {
      var currentStyleSheet = styleSheets[i];
      if (/smallscreenrendering/.test(currentStyleSheet.href)) {
        currentStyleSheet.disabled = !currentStyleSheet.disabled;
        this.setButtonState(!currentStyleSheet.disabled);
        return;
      }
      if (currentStyleSheet.ownerNode)
        lastOwnerNode = currentStyleSheet.ownerNode;
    }

    // we have to attach the stylesheet to the document...
    // what's the document root ? html ?
    if (docRootName == "html") {
      // let's create a link element
      var headElement = doc.getElementsByTagName("head")[0];
      var linkElement = doc.createElement("link");
      linkElement.setAttribute("rel", "stylesheet");
      linkElement.setAttribute("type", "text/css");
      linkElement.setAttribute("href", cSSRSheetURL);

      headElement.appendChild(linkElement);
    }
    else {
      // let's create a processing instruction
      var pi = doc.createProcessingInstruction("xml-stylesheet",
                 "type=\"text/css\" href=\"" + cSSRSheetURL + "\"" );
      if (lastOwnerNode) {
        lastOwnerNode.parentNode.insertBefore(pi,
              lastOwnerNode.nextSibling);
      }
      else {
        doc.insertBefore(pi, docRoot);
      }
    }
    this.setButtonState(true);
  },

  setButtonState : function (state) {
    var ssrState   = document.getElementById("webpanel-toggleSSR");
    if (state) {
      ssrState.setAttribute("ssr-active", "true");
      ssrState.setAttribute("checked", "true");
    }
    else {
      ssrState.removeAttribute("ssr-active");
      ssrState.setAttribute("checked", "flase");
    }
  },

  setResource: function() {
    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
                              .getService(Components.interfaces.nsIIOService);
    var uri = ioService.newURI("chrome://xsidebar/content/webpanels/", null, null);
    var res = ioService.getProtocolHandler("resource")
                       .QueryInterface(Components.interfaces.nsIResProtocolHandler);
    if (!res.hasSubstitution("xsidebar"))
      res.setSubstitution("xsidebar", uri);
  }

}